==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AssigningRadialStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningRadialStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningRadialStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningRadialStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningRadialStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningRadialStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningRadialStyleEventArgsBase", AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningRadialStyleEventArgsBaseDescriptionMetadata, 'AssigningRadialStyleEventArgsBaseDescriptionMetadata');
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningRadialStyleEventArgsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningRadialStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningRadialStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningRadialStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningRadialStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningRadialStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.k(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningRadialStyleEventArgsBaseDescriptionMetadata.b(a);
        a.ab("AssigningRadialStyleEventArgsBase", AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningRadialStyleEventArgsBaseDescriptionMetadata, 'AssigningRadialStyleEventArgsBaseDescriptionMetadata');
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningRadialStyleEventArgsBaseDescriptionMetadata };
